@@ -444,6 +444,10 @@ class Schema:
 
         for effectC in self.effects:
             effect = effectC.lower()
+            if effect == "stardust" and "starduster" in name:
+                sub = name.replace("stardust", "").strip()
+                if "starduster" not in sub:
+                    continue
             if effect == "showstopper" and "taunt: " not in name:
                 # if the effect is Showstopper and name does not include "Taunt: " or "Shred Alert", skip it
                 if "shred alert" not in name: continue
@@ -501,6 +505,10 @@ class Schema:
                 paintkit = paintkitC.lower()
                 if "mk.ii" in name and "mk.ii" not in paintkit:
                     continue
+                if "(green)" in name and "(green)" not in paintkit:
+                    continue
+                if "chilly" in name and 'chilly' not in paintkit:
+                    continue
                 if paintkit in name:
                     name = name.replace(paintkit, "").replace("|", "").strip()
                     item["paintkit"] = self.paintkits[paintkitC]
@@ -678,7 +686,7 @@ class Schema:
                     item["defindex"] = exclusiveGenuine[item['defindex']]
 
             if schemaItem["item_class"] == "supply_crate":
-                item["crateseries"] = self.getCrateSeriesList()[str(item["defindex"])]
+                item["crateseries"] = self.crateSeriesList[str(item["defindex"])]
             
             elif schemaItem["item_class"] != "supply_crate" and number is not None:
                 item["craftnumber"] = number
@@ -970,6 +978,9 @@ class Schema:
 
     # Get an array of item objects for craftable weapons
     def getCraftableWeaponsSchema(self):
+        # Includes Jungle Inferno update weapons
+        weaponsToInclude = {1178, 1179, 1180, 1181, 1190}
+
         weaponsToExclude = {
             # Exclude these weapons
             266, # Horseless Headless Horsemann's Headtaker
@@ -995,7 +1006,11 @@ class Schema:
 
         craftableWeapons = []
         for item in self.raw["schema"]["items"]:
-            if item["defindex"] not in weaponsToExclude and item["item_quality"] == 6 and item.get("craft_class") == "weapon": craftableWeapons.append(item)
+            if (
+                item["defindex"] in weaponsToInclude or
+                (item["defindex"] not in weaponsToExclude and item["item_quality"] == 6 and item.get("craft_class") == "weapon")
+                ): 
+                craftableWeapons.append(item)
 
         return craftableWeapons
 
@@ -1017,7 +1032,6 @@ class Schema:
         weapons = []
         for item in self.getCraftableWeaponsSchema():
             weapons.append(f"{item['defindex']};6")
-        [weapons.append(f"{defindex};6") for defindex in [1178, 1179, 1180, 1181, 1190]]
         return weapons
 
 
@@ -1051,10 +1065,6 @@ class Schema:
         items = None
         return crateseries
 
-    
-    def updateCrateSeriesList(self):    
-        self.crateSeriesList = self.getCrateSeriesList
-
 
     def getQualities(self):
         schema = self.raw["schema"]
@@ -1170,19 +1180,19 @@ class Schema:
 
 
     # Gets the name of an item with specific attributes
-    def getName(self, item, proper=True, usePipeForSkin=False):
+    def getName(self, item, proper=True, usePipeForSkin=False, scmFormat=False):
         schemaItem = self.getItemByDefindex(item["defindex"])
         if schemaItem is None: return None
 
         name = ""
 
-        if item.get("tradable") is False: name = "Non-Tradable "
+        if not scmFormat and item.get("tradable") is False: name = "Non-Tradable "
 
-        if item.get("craftable") is False: name += "Non-Craftable "
+        if not scmFormat and item.get("craftable") is False: name += "Non-Craftable "
 
         if item.get("quality2"):
             # Elevated quality
-            name += self.getQualityById(item["quality2"]) + ("(e)" if item["wear"] is not None or item["paintkit"] is not None else "") + " "
+            name += self.getQualityById(item["quality2"]) + ("(e)" if not scmFormat and (item["wear"] is not None or item["paintkit"] is not None) else "") + " "
 
         if ((item["quality"] != 6 and item["quality"] != 15 and item["quality"]  != 5) or
             (item["quality"]  == 5 and not item.get("effect")) or
@@ -1191,7 +1201,7 @@ class Schema:
             # If the quality is Unique (and is Elevated quality) or not Unique, Decorated, or Unusual, or if the quality is Unusual but it does not have an effect, or if the item can only be unusual, then add the quality
             name += self.getQualityById(item["quality"]) + " "
 
-        if item.get("effect"): name += self.getEffectById(item["effect"]) + " "
+        if not scmFormat and item.get("effect"): name += self.getEffectById(item["effect"]) + " "
 
         if item.get("festive") is True: name += "Festivized "
 
@@ -1218,11 +1228,21 @@ class Schema:
 
         if item.get("wear"): name += ' (' + ['Factory New', 'Minimal Wear', 'Field-Tested', 'Well-Worn', 'Battle Scarred'][item["wear"] - 1] + ')'
 
-        if item.get("crateseries"): name += " #" + str(item["crateseries"])
-        
-        if item.get("craftnumber"): name += ' #' + str(item["craftnumber"])
+        if item.get("crateseries"):
+            if "attributes" in schemaItem and schemaItem["attributes"][0]["class"] == "supply_crate_series":
+                hasAttr = True
+            else:
+                hasAttr = False
+            if scmFormat:
+                if hasAttr:
+                    name += " Series %23" + str(item["crateseries"])
+                # Else we don't need to add #number
+            else:
+                name += " #" + str(item["crateseries"])
+        elif item.get("craftnumber"):
+            name += ' #' + str(item["craftnumber"])
 
-        if item.get("paint"): name += f" (Paint: {self.getPaintNameByDecimal(item['paint'])})"
+        if not scmFormat and item.get("paint"): name += f" (Paint: {self.getPaintNameByDecimal(item['paint'])})"
 
         return name
 
